"""Admin interfaces
----------------

This module defines the dasf-broker-django
Admin interfaces.
"""

# Disclaimer
# ----------
#
# Copyright (C) 2022 Helmholtz-Zentrum Hereon
#
# This file is part of dasf-broker-django and is released under the
# EUPL-1.2 license.
# See LICENSE in the root of the repository for full licensing details.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the EUROPEAN UNION PUBLIC LICENCE v. 1.2 or later
# as published by the European Commission.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# EUPL-1.2 license for more details.
#
# You should have received a copy of the EUPL-1.2 license along with this
# program. If not, see https://www.eupl.eu/.


from django.contrib import admin  # noqa: F401
from guardian.admin import GuardedModelAdmin
from guardian.shortcuts import get_users_with_perms

from dasf_broker import models  # noqa: F401


@admin.register(models.DASFTopic)
class DASFTopicAdmin(GuardedModelAdmin):
    """An admin for :model:`dasf_broker.DASFTopic"""

    search_fields = [
        "slug",
    ]

    list_display = [
        "slug",
        "get_consumers",
        "get_producers",
        "is_public",
        "is_response_topic",
    ]

    list_filter = ["is_public", "is_response_topic"]

    @admin.display(description="Consumer(s)")  # type: ignore
    def get_consumers(self, obj: models.DASFTopic):
        return ", ".join(map(str, get_users_with_perms(obj, "can_consume")))

    @admin.display(description="Producer(s)")  # type: ignore
    def get_producers(self, obj: models.DASFTopic):
        return ", ".join(map(str, get_users_with_perms(obj, "can_produce")))
