"""Models
------

Models for the dasf-broker-django app.
"""

# Disclaimer
# ----------
#
# Copyright (C) 2022 Helmholtz-Zentrum Hereon
#
# This file is part of dasf-broker-django and is released under the
# EUPL-1.2 license.
# See LICENSE in the root of the repository for full licensing details.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the EUROPEAN UNION PUBLIC LICENCE v. 1.2 or later
# as published by the European Commission.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# EUPL-1.2 license for more details.
#
# You should have received a copy of the EUPL-1.2 license along with this
# program. If not, see https://www.eupl.eu/.


from __future__ import annotations

from django.db import models  # noqa: F401

from dasf_broker import app_settings  # noqa: F401


class DASFTopic(models.Model):
    """A topic for producing and consuming requests via websocket"""

    class Meta:
        permissions = (
            ("can_produce", "Can publish messages to the topic (Producer)."),
            ("can_consume", "Can consume messages to the topic (Consumer)."),
        )

    slug = models.SlugField(
        unique=True, help_text="Unique identifier for the topic."
    )

    is_public = models.BooleanField(
        default=False, help_text="Can everyone publish data to this topic?"
    )

    is_response_topic = models.BooleanField(
        default=False,
        help_text="Is this topic used only once for a single response?",
    )

    def __str__(self) -> str:
        return self.slug
